@@ -106,7 +106,7 @@ class Document(BaseModel):
 class Receiver(BaseModel):
     tax_identification_number: str
     name: str
-    iban: str
+    iban: Optional[str]
     address: Optional[str]
     building_number: Optional[str]
     postal_code: Optional[str]
